#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2011  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

# enable python3 by default
%bcond_without python3

# python2 is not available on RHEL > 7 and not needed on Fedora > 28
%if 0%{?rhel} > 7 || 0%{?fedora} > 28
# disable python2 by default
%bcond_with python2
%else
%bcond_without python2
%endif


Name:		qubes-gpg-split-dom0
Version:	2.0.54
Release:	1%{dist}
Summary:    Qubes policy for gpg split

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires: make
%if %{with python2}
BuildRequires: python-setuptools
BuildRequires: python2-rpm-macros
%endif
%if %{with python3}
BuildRequires: python3-rpm-macros
BuildRequires: python3-setuptools
BuildRequires: python3-devel
%endif
Requires:	gpg

Source0: qubes-gpg-split-%{version}.tar.gz

%description

%prep
%setup -q -n qubes-gpg-split-%{version}

%install
rm -rf $RPM_BUILD_ROOT
install -m 0664 -D qubes.Gpg.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.Gpg
install -m 0664 -D qubes.GpgImportKey.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.GpgImportKey
%{?with_python2:make -C tests install-dom0-py2 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python2}}
%{?with_python3:make -C tests install-dom0-py3 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python3}}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.Gpg
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.GpgImportKey
%if %{with python2}
%dir %{python2_sitelib}/splitgpg-*.egg-info
%{python2_sitelib}/splitgpg-*.egg-info/*
%{python2_sitelib}/splitgpg
%endif
%if %{with python3}
%dir %{python3_sitelib}/splitgpg-*.egg-info
%{python3_sitelib}/splitgpg-*.egg-info/*
%{python3_sitelib}/splitgpg
%endif

%changelog
* Tue Nov 09 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-app-linux-split-gpg.git

* Tue Nov 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 353e827
- version 2.0.54

* Wed Oct 27 2021 deeplow <deeplower@protonmail.com> - b3b72ed
- tests: retry "enter imap password" on fail

* Wed Oct 27 2021 deeplow <deeplower@protonmail.com> - 5f71ba8
- tests: support windows with role 'frame' or 'dialog'

* Wed Oct 27 2021 Alyssa Ross <hi@alyssa.is> - f48ef30
- Make fd path replacement length check clearer

* Wed Oct 27 2021 Alyssa Ross <hi@alyssa.is> - 089d1fb
- Fix off-by-one in fd path replacement

* Fri Oct 22 2021 deeplow <deeplower@protonmail.com> - 52cc3cc
- tests: improve resilience of OpenPGP button click

* Fri Oct 22 2021 deeplow <deeplower@protonmail.com> - f03ce50
- tests: check mail manually instead

* Tue Oct 19 2021 deeplow <deeplower@protonmail.com> - cb2ba73
- tests: make thunderbird user.js dynamically generated

* Mon Oct 18 2021 deeplow <deeplower@protonmail.com> - 471dd95
- tests: tb fix OpenPGP opening in tb91+

* Mon Oct 18 2021 deeplow <deeplower@protonmail.com> - c15b563
- tests: remove deprecated tb OpenPGP message code

* Fri Oct 15 2021 deeplow <deeplower@protonmail.com> - bc23eeb
- tests: more fixes for tb 91+

* Fri Oct 15 2021 deeplow <deeplower@protonmail.com> - b5a3446
- tests: fix bug where arguments were missing a space

* Fri Oct 15 2021 deeplow <deeplower@protonmail.com> - 19cbfe1
- tests: autotype IMAP password

* Thu Oct 14 2021 deeplow <deeplower@protonmail.com> - 8709c2d
- tests: remove autoconf and local account setup code

* Thu Oct 14 2021 deeplow <deeplower@protonmail.com> - 0069ad3
- tests: thunderbird use user.js for default profile

* Tue Oct 12 2021 deeplow <deeplower@protonmail.com> - 3c1b9ac
- test: add IMAP server as tb 91+ removed movemail

* Thu Sep 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6ddc1db
- version 2.0.53

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f3f72b9
- tests: option arguments parsing

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cd4e229
- tests: include stderr in the failure message

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c3301ff
- Add --display option to the parser

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 819f3bb
- Fix forbidden option reporting

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dd0ae88
- Add --default-recipient option to the parser

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 678a1b2
- Remove duplicated --fixed-list-mode

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3c8da0d
- Fix --with-colons declaration

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d0d8a42
- Properly handle gpg's command options

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c1b0e14
- Correctly mark --s2k-* options as requiring an argument

* Thu Sep 02 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 92835aa
- Tighten up parsing of file descriptors

* Thu Sep 02 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6a00456
- version 2.0.52

* Mon Aug 30 2021 deeplow <deeplower@protonmail.com> - ff8d3ec
- use functools wraps in decorator

* Mon Aug 30 2021 deeplow <deeplower@protonmail.com> - cdb1f13
- retry_if_failed add_local_account (now idempotent)

* Mon Aug 30 2021 deeplow <deeplower@protonmail.com> - e9c1fd0
- add retry_if_failed wrapper to setup function

* Mon Aug 30 2021 deeplow <deeplower@protonmail.com> - 74cce39
- tests: manage thunderbird through dedicated class

* Sat Aug 28 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7b259e9
- tests: avoid redirect to dogtail repo

* Fri Aug 06 2021 deeplow <deeplower@protonmail.com> - 2ce2563
- tests: remove creation of .gnupg (enigmail req.)

* Fri Aug 06 2021 deeplow <deeplower@protonmail.com> - 9db91b9
- tests: remove deprecated enigmail and tb<78 code

* Fri Aug 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9e8baea
- version 2.0.51

* Fri Jul 30 2021 deeplow <deeplower@protonmail.com> - e086143
- test: fix missed clicks on "open file" dialogue

* Wed Jul 28 2021 deeplow <deeplower@protonmail.com> - 4eddc75
- tests: generate w/ subkeys in remaining tests

* Thu Jul 15 2021 deeplow <deeplower@protonmail.com> - 8ee3294
- tests: master key sign-only + subkey

* Sat May 08 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - eae1af1
- spec: add BR make

* Tue Dec 08 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aa5f3dc
- version 2.0.50

* Sun Dec 06 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2d3a092
- tests: adjust key import dialog in debian-10

* Wed Dec 02 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - edc6a64
- Allow to override defined CFLAGS

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 225295b
- Add .gitlab-ci.yml

* Sat Nov 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 025ee29
- Improve reproducibility

* Fri Nov 13 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6749b2f
- version 2.0.49

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5acd498
- tests: try to get the main TB window, not any splash screen

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4155887
- rpm: skip python3-dogtail on CentOS

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2056385
- Adjust tests for Debian 10

* Sat Oct 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 908700a
- version 2.0.48

